@@ -1,5 +1,5 @@
 from pydantic import BaseModel
-from typing import Optional
+from typing import Optional, List
 from enum import IntEnum
 
 class AgriculturalProduction(BaseModel):
@@ -142,12 +142,13 @@ class ValueToLPDTO(BaseModel):
 
 class ValueFromLPDTO(BaseModel):
     farmId: int
-    yeardId: int
+    yearId: int
     agriculturalLand: float
     totalCurrentAssests: float
     agriculturalLandHectaresAdquisition: float
     longAndMediumTermLoans: float
     averageHAPrice: float
+    agriculturalLandHectares: float
 
 class CropDataDTO(BaseModel):
 
@@ -192,15 +193,19 @@ class AltitudeEnum(IntEnum):
 
 class ValueToSPDTO(BaseModel):
     farmCode: int
-    holderInfo: HolderInfoDTO
+    holderInfo: Optional[HolderInfoDTO] = None
     cod_RAGR: int
     cod_RAGR3: int
     technicalEconomicOrientation: int
     altitude: AltitudeEnum
     currentAssets: float
-    decoupledSubsidies: DecoupledSubsidiesDTO
-    crops: dict[str,CropDataDTO]
-    livestock: LivestockDTO
+    decoupledSubsidies: Optional[DecoupledSubsidiesDTO] = None
+    crops: dict[str, CropDataDTO]
+    livestock: Optional[LivestockDTO] = None
+
+class DataToSPDTO(BaseModel):
+    values: List[ValueToSPDTO]
+    arableProductGroupsNames: List[str]
 
 class IntermediateValueFromLP(BaseModel):
     farmId: int
