@@ -8,24 +8,7 @@ class SimulationScenario(BaseModel):
     yearId: int
     shortTermModelBranch: str
     longTermModelBranch: str
-    
-class SimulationRun(BaseModel):
-    id: Optional[int] = None
-    simulationScenarioId: int
-    logMessages: List[LogMessage]
-    overallStatus: OverallStatus
-    currentStage: SimulationStage
-    currentYear: int
-    currentSubStage: str
-    currentStageProgress: int
-    currentSubStageProgress: int
-
-class LogMessage(BaseModel):
-    timestamp: int
-    source: str
-    logLevel: LogLevel
-    title: str
-    description: str
+    horizon: int
 
 class LogLevel(IntEnum):
     TRACE = 5
@@ -36,6 +19,14 @@ class LogLevel(IntEnum):
     ERROR = 40
     CRITICAL = 50
 
+class LogMessage(BaseModel):
+    simulationRunId: int
+    timestamp: int
+    source: str
+    logLevel: LogLevel
+    title: str
+    description: str
+
 class OverallStatus(IntEnum):
     INPROGRESS = 1
     CANCELLED = 2
@@ -48,3 +39,13 @@ class SimulationStage(IntEnum):
     LANDMARKET = 3
     SHORTPERIOD = 4
     REALISATION = 5
+class SimulationRun(BaseModel):
+    id: Optional[int] = None
+    simulationScenarioId: int
+    logMessages: Optional[List[LogMessage]] = None
+    overallStatus: OverallStatus
+    currentStage: SimulationStage
+    currentYear: int
+    currentSubStage: str
+    currentStageProgress: int
+    currentSubStageProgress: int
